@@ -289,8 +289,10 @@ main (int argc, char **argv)
       case 'z': no_standard_input++; break;
       case '?': error_occurred++;
       }
-  if (error_occurred)
+  if (error_occurred) {
     cerr << "usage" sp argv[0] sp usage_message;
+    exit (-1);    
+  }
 				// Complain if the plot does not fits on page
   if (up < 0.) cerr <<
     "Warning: the plot may extend below the bottom of the page.\n";
