@@ -15,7 +15,11 @@ void*     memcpy _G_ARGS((void*, const void*, _G_size_t));
 void*     memmove _G_ARGS((void*, const void*, _G_size_t));
 void*     memset _G_ARGS((void*, int, _G_size_t));
 int       ffs _G_ARGS((int));
+#ifdef __OSF1__
+int	  getpagesize _G_ARGS((void));
+#else
 _G_size_t    getpagesize _G_ARGS((void));
+#endif
 void*     valloc _G_ARGS((_G_size_t));
 
 void      bcopy _G_ARGS((const void*, void*, _G_size_t));
