@@ -39,6 +39,7 @@ struct IntRep                    // internal Integer representations
 
 extern IntRep*  Ialloc(IntRep*, const unsigned short *, int, int, int);
 extern IntRep*  Icalloc(IntRep*, int);
+extern IntRep*  Icopy_ulong(IntRep*, unsigned long);
 extern IntRep*  Icopy_long(IntRep*, long);
 extern IntRep*  Icopy(IntRep*, const IntRep*);
 extern IntRep*  Iresize(IntRep*, int);
@@ -84,6 +85,7 @@ protected:
 public:
                   Integer();
                   Integer(long);
+                  Integer(unsigned long);
                   Integer(IntRep*);
                   Integer(const Integer&);
 
@@ -281,6 +283,8 @@ inline Integer::Integer(IntRep* r) :rep(r) {}
 
 inline Integer::Integer(long y) :rep(Icopy_long(0, y)) {}
 
+inline Integer::Integer(unsigned long y) :rep(Icopy_ulong(0, y)) {}
+
 inline Integer::Integer(const Integer&  y) :rep(Icopy(0, y.rep)) {}
 
 inline Integer::~Integer() { if (rep && !STATIC_IntRep(rep)) delete rep; }
@@ -661,12 +665,12 @@ inline void Integer::operator /= (long y)
 
 inline void Integer::operator %= (const Integer& y)
 {
-  mod(*this, y, *this);
+  *this = *this % y; // mod(*this, y, *this) doesn't work.
 }
 
 inline void Integer::operator %= (long y)
 {
-  mod(*this, y, *this);
+  *this = *this % y; // mod(*this, y, *this) doesn't work.
 }
 
 
