@@ -84,7 +84,7 @@ int testbit(long x, long b);
 
 #if !defined(IV)
 
-#ifndef hpux /* hpux defines this in math.h */
+#ifndef __hpux /* hpux defines this in math.h */
 inline double abs(double arg) 
 {
   return (arg < 0.0)? -arg : arg;
@@ -121,7 +121,7 @@ inline long sqr(long arg)
   return arg * arg;
 }
 
-#ifndef hpux /* hpux defines this in math.h */
+#ifndef __hpux /* hpux defines this in math.h */
 inline double sqr(double arg)
 {
   return arg * arg;
