@@ -694,11 +694,11 @@ void Splaytest()
 
 
 
-main(int argv, char** argc)
+main(int argc, char** argv)
 {
-  if (argv > 1)
+  if (argc > 1)
   {
-    SIZE = abs(atoi(argc[1]));
+    SIZE = abs(atoi(argv[1]));
     SIZE &= ~1;
   }
   else
